@@ -17,5 +17,5 @@ print('使用有问题 or 提交你的功能需求 or 参与项目开发')
 print('1、全部功能【视频 & 文字】教程：https://www.python-office.com/')
 print('2、请+【项目交流群】：http://t.cn/A65MiFvH')
 print('3、本开源项目的【代码仓库】：https://github.com/CoderWanFeng/python-office')
-print('4、【常见问题】：http://t.cn/A6KCcRPn')
+print('4、【常见问题】：https://www.python-office.com/ref/qaq.html')
 print(SPLIT_LINE)
